@@ -6,8 +6,9 @@ import logging
 import os
 import sys
 from argparse import Namespace
+from collections.abc import Sequence
 from pathlib import Path
-from typing import Any, Callable, Sequence
+from typing import Any, Callable
 
 from ansiblelint.config import DEFAULT_KINDS, DEFAULT_WARN_LIST, PROFILES
 from ansiblelint.constants import (
@@ -22,6 +23,7 @@ from ansiblelint.file_utils import (
     guess_project_dir,
     normpath,
 )
+from ansiblelint.loaders import IGNORE_FILE
 from ansiblelint.schemas.main import validate_file_schema
 from ansiblelint.yaml_utils import clean_json
 
@@ -56,6 +58,11 @@ def expand_to_normalized_paths(
 def load_config(config_file: str) -> dict[Any, Any]:
     """Load configuration from disk."""
     config_path = None
+
+    if config_file == "/dev/null":
+        _logger.debug("Skipping config file as it was set to /dev/null")
+        return {}
+
     if config_file:
         config_path = os.path.abspath(config_file)
         if not os.path.exists(config_path):
@@ -224,7 +231,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         default=False,
         action="store_true",
         help="List all the rules. For listing rules only the following formats "
-        "for argument -f are supported: {plain, rich, md}",
+        "for argument -f are supported: {brief, full, md} with 'brief' as default.",
     )
     listing_group.add_argument(
         "-T",
@@ -238,10 +245,11 @@ def get_cli_parser() -> argparse.ArgumentParser:
         "-f",
         "--format",
         dest="format",
-        default="rich",
+        default=None,
         choices=[
-            "rich",
-            "plain",
+            "brief",
+            # "plain",
+            "full",
             "md",
             "json",
             "codeclimate",
@@ -252,6 +260,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         ],
         help="stdout formatting, json being an alias for codeclimate. (default: %(default)s)",
     )
+    parser.add_argument("--sarif-file", default=None, help="SARIF output file")
     parser.add_argument(
         "-q",
         dest="quiet",
@@ -280,8 +289,8 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="progressive",
         default=False,
         action="store_true",
-        help="Return success if number of violations compared with"
-        "previous git commit has not increased. This feature works"
+        help="Return success if number of violations compared with "
+        "previous git commit has not increased. This feature works "
         "only in git repositories.",
     )
     parser.add_argument(
@@ -289,7 +298,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="project_dir",
         default=".",
         help="Location of project/repository, autodetected based on location "
-        " of configuration file.",
+        "of configuration file.",
     )
     parser.add_argument(
         "-r",
@@ -363,7 +372,15 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="skip_list",
         default=[],
         action="append",
-        help="only check rules whose id/tags do not " "match these values",
+        help="only check rules whose id/tags do not match these values. \
+            e.g: --skip-list=name,run-once",
+    )
+    parser.add_argument(
+        "--generate-ignore",
+        dest="generate_ignore",
+        action="store_true",
+        default=False,
+        help="Generate a text file '.ansible-lint-ignore' that ignores all found violations. Each line contains filename and rule id separated by a space.",
     )
     parser.add_argument(
         "-w",
@@ -410,6 +427,14 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="config_file",
         help="Specify configuration file to use. By default it will look for '.ansible-lint' or '.config/ansible-lint.yml'",
     )
+    parser.add_argument(
+        "-i",
+        "--ignore-file",
+        dest="ignore_file",
+        type=Path,
+        default=None,
+        help=f"Specify ignore file to use. By default it will look for '{IGNORE_FILE.default}' or '{IGNORE_FILE.alternative}'",
+    )
     parser.add_argument(
         "--offline",
         dest="offline",
@@ -425,8 +450,7 @@ def get_cli_parser() -> argparse.ArgumentParser:
         dest="lintables",
         nargs="*",
         action="extend",
-        help="One or more files or paths. When missing it will "
-        " enable auto-detection mode.",
+        help="One or more files or paths. When missing it will enable auto-detection mode.",
     )
 
     return parser
@@ -462,6 +486,7 @@ def merge_config(file_config: dict[Any, Any], cli_config: Namespace) -> Namespac
         "loop_var_prefix": None,
         "project_dir": ".",
         "profile": None,
+        "sarif_file": None,
     }
 
     if not file_config:
@@ -524,10 +549,16 @@ def get_config(arguments: list[str]) -> Namespace:
     options = parser.parse_args(arguments)
 
     # docs is not document, being used for internal documentation building
-    if options.list_rules and options.format not in ["plain", "rich", "md", "docs"]:
+    if options.list_rules and options.format not in [
+        None,
+        "brief",
+        "full",
+        "md",
+        "docs",
+    ]:
         parser.error(
             f"argument -f: invalid choice: '{options.format}'. "
-            f"In combination with argument -L only 'plain', "
+            f"In combination with argument -L only 'brief', "
             f"'rich' or 'md' are supported with -f."
         )
 
